@@ -92,7 +92,6 @@ OC.L10N.register(
     "Favorite" : "Meter en Favoritos",
     "Unread" : "Ensin lleer",
     "Read" : "Lleer",
-    "Select" : "Seleicionar",
     "Edit tags" : "Editar le setiquetes",
     "Move thread" : "Mover el filu",
     "Archive thread" : "Archivar el filu",
@@ -104,7 +103,6 @@ OC.L10N.register(
     "Download message" : "Baxar el mensaxe",
     "Could not delete message" : "Nun se pudo desaniciar el mensaxe",
     "Could not archive message" : "Nun se pudo archivar el mensaxe",
-    "Forward" : "Avanzar",
     "Load more" : "Cargar más",
     "Report this bug" : "Informar d'esti fallu",
     "All day" : "Tol día",
@@ -118,6 +116,7 @@ OC.L10N.register(
     "You already reacted to this invitation" : "Yá reaicionesti a esta invitación",
     "You have been invited to an event" : "Convidáronte a un eventu",
     "This event was cancelled" : "Esti eventu anulóse",
+    "Select" : "Seleicionar",
     "Comment" : "Comentariu",
     "Accept" : "Aceptar",
     "Decline" : "Refugar",
@@ -137,7 +136,9 @@ OC.L10N.register(
     "Loading messages …" : "Cargando los mensaxes…",
     "No more submailboxes in here" : "Equí nun hai más sobandexes",
     "Important info" : "Información importante",
+    "Forward" : "Avanzar",
     "Move message" : "Mover el mensaxe",
+    "Translate" : "Traducir",
     "View source" : "Ver l'orixe",
     "Message body" : "Cuerpu del mensaxe",
     "Save to Files" : "Guardar en Ficheros",
@@ -197,6 +198,8 @@ OC.L10N.register(
     "Add" : "Amestar",
     "Copied email address to clipboard" : "La direición de corréu electrónicu copióse nel cartafueyu",
     "Could not copy email address to clipboard" : "Nun se pudo copiar la direición de corréu electrónicu nel cartafueyu",
+    "Show less" : "Amosar menos",
+    "Show more" : "Amosar más",
     "Close" : "Zarrar",
     "Search parameters" : "Parámetros de busca",
     "Body" : "Cuerpu",
@@ -235,6 +238,12 @@ OC.L10N.register(
     "Message source" : "Orixe del mensaxe",
     "Go to latest message" : "Dir al últimu mensaxe",
     "Go to newest message" : "Dir al mensaxe más nuevu",
+    "Translate message" : "Traducir el mensaxe",
+    "Translating" : "Traduciendo",
+    "Copy translated text" : "Copiar el testu traducíu",
+    "The message could not be translated" : "Nun se pudo traducir el mensaxe",
+    "Translation copied to clipboard" : "La traducción copióse al cartafueyu",
+    "Translation could not be copied" : "Nun se pudo copiar la traducción",
     "Untitled event" : "Eventu ensin títulu",
     "Airplane" : "Avión",
     "Train" : "Tren",
