@@ -22,6 +22,7 @@ OC.L10N.register(
     "Sent date is in the future" : "Datum odeslání se nachází v budoucnosti",
     "Some addresses in this message are not matching the link text" : "Některé adresy v této zprávě se neshodují s textem odkazu",
     "Reply-To email: %1$s  is different from the sender email: %2$s" : "E-mail na který odpovídat: %1$s se liší od e-mailu odesilatele: %2$s",
+    "Mail Transport configuration" : "Nastavení transportu e-mailů",
     "💌 A mail app for Nextcloud" : "💌 E-mailová aplikace pro Nextcloud",
     "Your session has expired. The page will be reloaded." : "Platnost vaší relace skončila. Stránka bude znovu načtena.",
     "Drafts are saved in:" : "Koncepty jsou ukládány do:",
@@ -231,6 +232,7 @@ OC.L10N.register(
     "No messages in this mailbox" : "V této schránce nejsou žádné zprávy",
     "No messages" : "Žádné zprávy",
     "Draft: " : "Koncept:",
+    "This summary was AI generated" : "Toto shrnutí bylo vytvořeno AI",
     "Encrypted message" : "Šifrovaná zpráva",
     "This message is unread" : "Tato zpráva je nepřečtená",
     "Unfavorite" : "Odebrat z oblíbených",
@@ -240,8 +242,6 @@ OC.L10N.register(
     "Unimportant" : "Označit jako nedůležité",
     "Mark not spam" : "Zrušit označení jako spam",
     "Mark as spam" : "Označit jako spam",
-    "Unselect" : "Zrušit výběr",
-    "Select" : "Vybrat",
     "Edit tags" : "Upravit štítky",
     "Snooze" : "Odložit",
     "Unsnooze" : "Zrušit odložení",
@@ -268,8 +268,19 @@ OC.L10N.register(
     "Could not snooze thread" : "Vlákno se nepodařilo odložit",
     "Thread was unsnoozed" : "Odložení vlákna bylo zrušeno",
     "Could not unsnooze thread" : "Nepodařilo se zrušit odložení vlákna",
-    "Forward" : "Přeposlat",
     "Load more" : "Načíst více",
+    "_Mark {number} read_::_Mark {number} read_" : ["Označit {number} jako přečtený","Označit {number} jako přečtené","Označit {number} jako přečtené","Označit {number} jako přečtené"],
+    "_Mark {number} unread_::_Mark {number} unread_" : ["Označit {number} jako nepřečtený","Označit {number} jako nepřečtené","Označit {number} jako nepřečtených","Označit {number} jako nepřečtené"],
+    "_Mark {number} as important_::_Mark {number} as important_" : ["Označit {number} jako důležité","Označit {number} jako důležité","Označit {number} jako důležité","Označit {number} jako důležité"],
+    "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["Označit {number} jako nedůležité","Označit {number} jako nedůležité","Označit {number} jako nedůležité","Označit {number} jako nedůležité"],
+    "_Unfavorite {number}_::_Unfavorite {number}_" : ["Odebrat {number} z oblíbených","Odebrat {number} z oblíbených","Odebrat {number} z oblíbených","Odebrat {number} z oblíbených"],
+    "_Favorite {number}_::_Favorite {number}_" : ["Přidat {number} do oblíbených","Přidat {number} do oblíbených","Přidat {number} do oblíbených","Přidat {number} do oblíbených"],
+    "_Unselect {number}_::_Unselect {number}_" : ["Zrušit výběr {number}","Zrušit výběr {number}","Zrušit výběr {number}","Zrušit výběr {number}"],
+    "_Mark {number} as spam_::_Mark {number} as spam_" : ["Označit {number} jako nevyžádanou poštu","Označit {number} jako nevyžádanou poštu","Označit {number} jako nevyžádanou poštu","Označit {number} jako nevyžádanou poštu"],
+    "_Mark {number} as not spam_::_Mark {number} as not spam_" : ["Označit {number} jako chtěnou poštu","Označit {number} jako chtěnou poštu","Označit {number} jako chtěnou poštu","Označit {number} jako chtěnou poštu"],
+    "_Edit tags for {number}_::_Edit tags for {number}_" : ["Upravit štítky pro {number}","Upravit štítky pro {number}","Upravit štítky pro {number}","Upravit štítky pro {number}"],
+    "_Move {number} thread_::_Move {number} threads_" : ["Přesunout {number} vlákno","Přesunout {number} vlákna","Přesunout {number} vláken","Přesunout {number} vlákna"],
+    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Přeposlat {number} jako přílohu","Přeposlat {number} jako přílohy","Přeposlat {number} jako přílohy","Přeposlat {number} jako přílohy"],
     "Report this bug" : "Nahlásit tuto chybu",
     "All day" : "Celý den",
     "Select calendar" : "Vybrat kalendář",
@@ -284,6 +295,7 @@ OC.L10N.register(
     "You have been invited to an event" : "Byly jste pozvání do události",
     "This event was cancelled" : "Tato událost byla zrušena",
     "Save to" : "Uložit do",
+    "Select" : "Vybrat",
     "Comment" : "Komentář",
     "Accept" : "Přijmout",
     "Decline" : "Odmítnout",
@@ -322,7 +334,9 @@ OC.L10N.register(
     "Notify the sender" : "Odeslat potvrzení",
     "You sent a read confirmation to the sender of this message." : "Odesilateli jste poslali potvrzení o přečtení této zprávy.",
     "Could not send mdn" : "Mdn se nepodařilo odeslat",
+    "Forward" : "Přeposlat",
     "Move message" : "Přesunout zprávu",
+    "Translate" : "Překládání",
     "Forward message as attachment" : "Přeposlat zprávu jako přílohu",
     "View source" : "Zobrazit zdroj",
     "Print message" : "Vytisknout zprávu",
@@ -454,6 +468,8 @@ OC.L10N.register(
     "Add" : "Přidat",
     "Copied email address to clipboard" : "E-mailová adresa zkopírována do schránky",
     "Could not copy email address to clipboard" : "E-mailovou adresu se nepodařilo zkopírovat do schránky",
+    "Show less" : "Zobrazit méně",
+    "Show more" : "Zobrazit více",
     "Search in mailbox" : "Hledat ve schránce",
     "Close" : "Zavřít",
     "Search parameters" : "Parametry hledání",
@@ -539,10 +555,22 @@ OC.L10N.register(
     "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "Tato zpráva obsahuje neověřený digitální S/MIME podpis. Zpráva tedy mohla být po odeslání změněna nebo není certifikát podepisujícího považován za důvěryhodný.",
     "Unsubscribe request sent" : "Požadavek na zrušení přihlášení se k oběru odeslán",
     "Could not unsubscribe from mailing list" : "Nepodařilo se zrušit přihášení k odběru e-mailové distribuce",
+    "Please wait for the message to load" : "Vyčkejte na načtení zprávy",
     "Go to latest message" : "Přejít na poslední zprávu",
     "Go to newest message" : "Přejít na nejnovější zprávu",
     "Thread summary" : "Shrnutí vlákna",
     "{name} Assistant" : "{name} asistent",
+    "Translate message" : "Přeložit zprávu",
+    "Source language to translate from" : "Zdrojový jazyk, ze kterého přeložit",
+    "Translate from" : "Přeložit z",
+    "Target language to translate into" : "Cílový jazyk, do kterého přeložit",
+    "Translate to" : "Přeložit do",
+    "Translating" : "Překládá se",
+    "Copy translated text" : "Zkopírovat přeložený text",
+    "Please select languages to translate to and from" : "Vyberte jazyk z kterého a do kterého překládat",
+    "The message could not be translated" : "Zprávu se nepodařilo přeložit",
+    "Translation copied to clipboard" : "Překlad zkopírován do schránky",
+    "Translation could not be copied" : "Překlad se nepodařilo zkopírovat",
     "Disable trash retention by leaving the field empty or setting it to 0. Only mails deleted after enabling trash retention will be processed." : "Pokud chcete ponechávání v koši vypnout, kolonku nevyplňujte nebo zadejte hodnotu 0 (nula). Zpracovány budou pouze ty e-maily, smazaná po zapnutí ponechávání v koši.",
     "No senders are trusted at the moment." : "V tuto chvíli nejsou mezi důvěryhodnými žádní odesílatelé.",
     "Could not remove trusted sender {sender}" : "Nepodařilo se odebrat důvěryhodného odesílatele {sender}",
@@ -744,9 +772,6 @@ OC.L10N.register(
     "The link leads to %s" : "Odkaz vede na %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Pokud nechcete tuto stránku navštívit, můžete se vrátit do <a href=\"%s\">e-mailu</a>.",
     "Continue to %s" : "Pokračovat na %s",
-    "Sieve filter rules" : "Pravidla sieve filtru",
-    "Sieve filter server" : "Filtrovací server sieve",
-    "Account creation" : "Vytváření účtů",
-    "Sieve is a powerful language for writing filters for your mailbox. You can manage the sieve scripts in Mail if your email service supports it." : "Sieve je mocný jazyk pro psaní filtrovacích pravidel pro e-mailovou schránku. Pokud je vámi využívaná e-mailová služba podporuje, je možné zpravovat sieve skripty v aplikaci E-mail."
+    "Unselect" : "Zrušit výběr"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
