@@ -175,8 +175,6 @@ OC.L10N.register(
     "Unimportant" : "Ikke vigtig",
     "Mark not spam" : "Markér ikke spam",
     "Mark as spam" : "Marker som spam",
-    "Unselect" : "Fravælg",
-    "Select" : "Vælg",
     "Edit tags" : "Redigér mærker",
     "Move thread" : "Flyt tråden",
     "Delete thread" : "Slet tråd",
@@ -188,10 +186,22 @@ OC.L10N.register(
     "Download message" : "Download besked",
     "Blind copy recipients only" : "Kun blinde kopi-modtagere",
     "No subject" : "Intet emne",
+    "Set reminder for later today" : "Sæt påmindelse for senere i dag",
+    "Set reminder for tomorrow" : "Sæt påmindelse for i morgen",
+    "Set reminder for this weekend" : "Sæt påmindelse for denne weekend",
+    "Set reminder for next week" : "Sæt påmindelse for næste weekend",
     "No trash mailbox configured" : "Der er ikke konfigureret nogen papirkurvspostkasse",
     "Could not delete message" : "Kunne ikke slette beskeden",
-    "Forward" : "Videresend",
     "Load more" : "Hent flere",
+    "_Mark {number} read_::_Mark {number} read_" : ["Marker {number} læst","Marker {number} læst"],
+    "_Mark {number} unread_::_Mark {number} unread_" : ["Marker {number} som ulæst","Marker {number} som ulæst"],
+    "_Mark {number} as important_::_Mark {number} as important_" : ["Marker {number} som vigtigt","Marker {number} som vigtigt"],
+    "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["Marker {number} som uvigtig","Marker {number} som uvigtig"],
+    "_Unfavorite {number}_::_Unfavorite {number}_" : ["Fjern foretrukken {number}","Fjern foretrukken {number}"],
+    "_Favorite {number}_::_Favorite {number}_" : ["Favorit {number}","Favorit {number}"],
+    "_Unselect {number}_::_Unselect {number}_" : ["Fravælg {number}","Fravælg {number}"],
+    "_Move {number} thread_::_Move {number} threads_" : ["Flyt {number} tråd","Flyt {number} tråde"],
+    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Videresend {number} som vedhæftet fil","Videresend {number} som vedhæftet fil"],
     "Report this bug" : "Rapporter denne fejl",
     "All day" : "Hele dagen",
     "Description" : "Beskrivelse",
@@ -205,6 +215,7 @@ OC.L10N.register(
     "You have been invited to an event" : "Du er blevet inviteret til en begivenhed",
     "This event was cancelled" : "Denne begivenhed blev aflyst",
     "Save to" : "Gem til",
+    "Select" : "Vælg",
     "Comment" : "Kommentér",
     "Accept" : "Accepter",
     "Decline" : "Afvis",
@@ -227,7 +238,9 @@ OC.L10N.register(
     "Other" : "Andet",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Beskeder vil automatisk blive markeret som vigtige baseret på, hvilke meddelelser du har interageret med eller markeret som vigtige. I begyndelsen skal du muligvis manuelt ændre vigtigheden for at lære systemet, men det vil forbedres med tiden.",
     "The sender of this message has asked to be notified when you read this message." : "Afsenderen af denne besked har bedt om at blive underrettet, når du læser denne besked.",
+    "Forward" : "Videresend",
     "Move message" : "Flyt besked",
+    "Translate" : "Oversæt",
     "Forward message as attachment" : "Videresend besked som vedhæftet fil",
     "View source" : "Vis kildekode",
     "Choose a folder to store the attachment in" : "Vælg den mappe, hvor vedhæftningen skal gemmes i",
@@ -271,6 +284,7 @@ OC.L10N.register(
     "Sending …" : "Sender ...",
     "Warning sending your message" : "Advarsel om at sende din besked",
     "Send anyway" : "Send alligevel",
+    "Draft" : "Kladde",
     "Reply" : "Besvar",
     "No sent mailbox configured. Please pick one in the account settings." : "Ingen sendt postkasse konfigureret. Vælg en i kontoindstillingerne.",
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Du prøver at sende til mange modtagere i Til og/eller Cc. Overvej at bruge Bcc til at skjule modtageradresser.",
@@ -370,7 +384,6 @@ OC.L10N.register(
     "Redirect" : "Omdiriger",
     "The link leads to %s" : "Linket fører til %s",
     "Continue to %s" : "Videre til %s",
-    "Sieve filter rules" : "Sieve filter regler",
-    "Sieve filter server" : "Sigt filter server"
+    "Unselect" : "Fravælg"
 },
 "nplurals=2; plural=(n != 1);");
