@@ -81,18 +81,16 @@ OC.L10N.register(
     "Unfavorite" : "Malpliŝatati",
     "Favorite" : "Pliŝatati",
     "Read" : "Legi",
-    "Unselect" : "Malelekti",
-    "Select" : "Elekti",
     "Edit tags" : "Redakti etikedojn",
     "More actions" : "Pliaj agoj",
     "Back" : "Antaŭen",
     "Blind copy recipients only" : "Nur blindkopiaj ricevontoj",
-    "Forward" : "Antaŭen",
     "Report this bug" : "Raporti tiun problemon",
     "All day" : "Tuttage",
     "Description" : "Priskribo",
     "Create" : "Krei",
     "Could not create event" : "Ne eblis krei okazaĵon",
+    "Select" : "Elekti",
     "Comment" : "Komento",
     "Accept" : "Akcepti",
     "Decline" : "Malakcepti",
@@ -101,6 +99,8 @@ OC.L10N.register(
     "Could not open mailbox" : "Ne eblis malfermi poŝtkesto",
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indeksas viajn mesaĝojn. Tio eble daŭrus iom pli longe por pli grandaj poŝtkestoj.",
     "Other" : "Alia",
+    "Forward" : "Antaŭen",
+    "Translate" : "Traduku",
     "Choose a folder to store the attachment in" : "Elektu dosierujon en kiu konservi la kunsendaĵon",
     "Import into calendar" : "Importi en kalendaron",
     "Download attachment" : "Elŝuti kunsendaĵon",
@@ -129,6 +129,8 @@ OC.L10N.register(
     "Message" : "Mesaĝo",
     "Copy to clipboard" : "Kopii tondejen",
     "Add" : "Aldoni",
+    "Show less" : "Montri malpli",
+    "Show more" : "Montri pli",
     "Close" : "Malfermi",
     "Date" : "Date",
     "Tags" : "Etikedoj",
@@ -190,6 +192,7 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Alklaku ĉi tie, ĉu vi ne estos aŭtomate alidirektita post kelkaj sekundoj.",
     "Redirect" : "Alidirekto",
     "The link leads to %s" : "La ligilo iras al %s",
-    "Continue to %s" : "Daŭrigi al %s"
+    "Continue to %s" : "Daŭrigi al %s",
+    "Unselect" : "Malelekti"
 },
 "nplurals=2; plural=(n != 1);");
