@@ -184,8 +184,6 @@ OC.L10N.register(
     "Unimportant" : "No importante",
     "Mark not spam" : "Marcar como no spam",
     "Mark as spam" : "Marcar como spam",
-    "Unselect" : "Deseleccionar",
-    "Select" : "Seleccionar",
     "Edit tags" : "Editar etiquetas",
     "Move thread" : "Mover hilo",
     "Archive thread" : "Archivar hilo",
@@ -201,8 +199,16 @@ OC.L10N.register(
     "No trash mailbox configured" : "No se ha configurado una bandeja de papelera",
     "Could not delete message" : "No se pudo eliminar el mensaje",
     "Could not archive message" : "No se pudo archivar el mensaje",
-    "Forward" : "Adelante",
     "Load more" : "Cargar más",
+    "_Mark {number} read_::_Mark {number} read_" : ["Marcar {number} como leído","Marcar {number} como leído","Marcar {number} como leído"],
+    "_Mark {number} unread_::_Mark {number} unread_" : ["Marcar {number} como no leído","Marcar {number} como no leído","Marcar {number} como no leído"],
+    "_Mark {number} as important_::_Mark {number} as important_" : ["Marcar {number} como importante","Marcar {number} como importante","Marcar {number} como importante"],
+    "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["Marcar {number} como no importante","Marcar {number} como no importante","Marcar {number} como no importante"],
+    "_Unfavorite {number}_::_Unfavorite {number}_" : ["No marcar {number} como favorito","No marcar {number} como favorito","No marcar {number} como favorito"],
+    "_Favorite {number}_::_Favorite {number}_" : ["Marcar {number} como favorito","Marcar {number} como favorito","Marcar {number} como favorito"],
+    "_Unselect {number}_::_Unselect {number}_" : ["No seleccionar {number}","No seleccionar {number}","No seleccionar {number}"],
+    "_Move {number} thread_::_Move {number} threads_" : ["Mover {number} hilo","Mover {number} hilos","Mover {number} hilos"],
+    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Reenviar {number} como adjunto","Reenviar {number} como adjunto","Reenviar {number} como adjunto"],
     "Report this bug" : "Informar de este error",
     "All day" : "Todo el día",
     "Select calendar" : "Seleccionar calendario",
@@ -217,6 +223,7 @@ OC.L10N.register(
     "You have been invited to an event" : "Has sido invitado a un evento",
     "This event was cancelled" : "Este evento fue cancelado",
     "Save to" : "Guardar en",
+    "Select" : "Seleccionar",
     "Comment" : "Comentario",
     "Accept" : "Aceptar",
     "Decline" : "Declinar",
@@ -248,7 +255,9 @@ OC.L10N.register(
     "Notify the sender" : "Notificar al remitente",
     "You sent a read confirmation to the sender of this message." : "Enviaste una confirmación de lectura al remitente de este mensaje.",
     "Could not send mdn" : "No se pudo enviar la notificación de lectura",
+    "Forward" : "Adelante",
     "Move message" : "Mover mensaje",
+    "Translate" : "Traducir",
     "Forward message as attachment" : "Reenviar mensaje como adjunto",
     "View source" : "Ver origen",
     "Download thread data for debugging" : "Descargar datos del hilo para depuración",
@@ -351,6 +360,8 @@ OC.L10N.register(
     "Add" : "Agregar",
     "Copied email address to clipboard" : "Dirección de correo electrónico copiada al portapapeles",
     "Could not copy email address to clipboard" : "No se pudo copiar la dirección de correo electrónico al portapapeles",
+    "Show less" : "Mostrar menos",
+    "Show more" : "Mostrar más",
     "Search in mailbox" : "Buscar en el correo",
     "Close" : "Cerrar",
     "Search parameters" : "Parámetros de búsqueda",
@@ -417,6 +428,16 @@ OC.L10N.register(
     "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "Este mensaje contiene una firma digital S/MIME no verificada. El mensaje podría haber sido modificado desde que fue enviado o el certificado del firmante no es confiable.",
     "Unsubscribe request sent" : "Solicitud de cancelación de suscripción enviada",
     "Could not unsubscribe from mailing list" : "No se pudo cancelar la suscripción a la lista de correo",
+    "Translate message" : "Traducir mensaje",
+    "Source language to translate from" : "Idioma de origen para traducir",
+    "Translate from" : "Traducir desde",
+    "Target language to translate into" : "Idioma de destino para la traducción",
+    "Translate to" : "Traducir a",
+    "Translating" : "Traduciendo",
+    "Copy translated text" : "Copiar texto traducido",
+    "The message could not be translated" : "No se pudo traducir el mensaje",
+    "Translation copied to clipboard" : "Traducción copiada al portapapeles",
+    "Translation could not be copied" : "No se pudo copiar la traducción",
     "No senders are trusted at the moment." : "No hay remitentes confiables en este momento.",
     "Could not remove trusted sender {sender}" : "No se pudo eliminar el remitente confiable {sender}",
     "(organizer)" : "(organizador)",
@@ -571,7 +592,6 @@ OC.L10N.register(
     "The link leads to %s" : "La liga lleva a %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Si no deseas visitar esa página, puedes regresar a <a href=\"%s\">Correo</a>.",
     "Continue to %s" : "Continuar a %s",
-    "Sieve filter rules" : "Reglas de filtro sieve",
-    "Sieve filter server" : "Servidor de filtro sieve"
+    "Unselect" : "Deseleccionar"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
