@@ -47,20 +47,21 @@ OC.L10N.register(
     "Confirm" : "Kinnita",
     "Favorite" : "Lemmik",
     "Read" : "Lugemine",
-    "Select" : "Vali",
     "Edit tags" : "Muuda silte",
     "Back" : "Tagasi",
     "Create event" : "Lisa sündmus",
-    "Forward" : "Edasi",
     "All day" : "Kogu päev",
     "Description" : "Kirjeldus",
     "Create" : "Loo",
+    "Select" : "Vali",
     "Comment" : "Kommentaar",
     "Accept" : "Nõustu",
     "Decline" : "Keeldu",
     "Remove" : "Eemalda",
     "email" : "e-post",
     "Other" : "Muu",
+    "Forward" : "Edasi",
+    "Translate" : "Tõlgi",
     "Choose a folder to store the attachment in" : "Vali kaust, kuhu manus salvestada",
     "Unnamed" : "Nimeta",
     "Move" : "Liiguta",
@@ -83,6 +84,7 @@ OC.L10N.register(
     "Clear" : "Tühjenda",
     "Custom" : "Kohandatud",
     "Tag already exists" : "Silt on juba olemas",
+    "Copy translated text" : "Kopeeri tõlgitud tekst",
     "Actions" : "Tegevused",
     "Priority" : "Prioriteet",
     "Reset" : "Lähtesta",
