@@ -194,8 +194,6 @@ OC.L10N.register(
     "Unimportant" : "Unimportant",
     "Mark not spam" : "Mark not spam",
     "Mark as spam" : "Mark as spam",
-    "Unselect" : "لغو انتخاب",
-    "Select" : "انتخاب",
     "Edit tags" : "ویرایش تگ ها",
     "Snooze" : "Snooze",
     "Move thread" : "Move thread",
@@ -219,8 +217,16 @@ OC.L10N.register(
     "Could not archive message" : "Could not archive message",
     "Thread was snoozed" : "Thread was snoozed",
     "Could not snooze thread" : "Could not snooze thread",
-    "Forward" : "فرستادن",
     "Load more" : "Load more",
+    "_Mark {number} read_::_Mark {number} read_" : ["Mark {number} read","Mark {number} read"],
+    "_Mark {number} unread_::_Mark {number} unread_" : ["Mark {number} unread","Mark {number} unread"],
+    "_Mark {number} as important_::_Mark {number} as important_" : ["Mark {number} as important","Mark {number} as important"],
+    "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["Mark {number} as unimportant","Mark {number} as unimportant"],
+    "_Unfavorite {number}_::_Unfavorite {number}_" : ["Unfavorite {number}","Unfavorite {number}"],
+    "_Favorite {number}_::_Favorite {number}_" : ["Favorite {number}","Favorite {number}"],
+    "_Unselect {number}_::_Unselect {number}_" : ["Unselect {number}","Unselect {number}"],
+    "_Move {number} thread_::_Move {number} threads_" : ["Move {number} thread","Move {number} threads"],
+    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Forward {number} as attachment","Forward {number} as attachment"],
     "Report this bug" : "گزارش این اشکال",
     "All day" : "تمام روز",
     "Select calendar" : "Select calendar",
@@ -235,6 +241,7 @@ OC.L10N.register(
     "You have been invited to an event" : "You have been invited to an event",
     "This event was cancelled" : "This event was cancelled",
     "Save to" : "Save to",
+    "Select" : "انتخاب",
     "Comment" : "نظر",
     "Accept" : "تایید",
     "Decline" : "کاهش می یابد",
@@ -266,7 +273,9 @@ OC.L10N.register(
     "Notify the sender" : "Notify the sender",
     "You sent a read confirmation to the sender of this message." : "You sent a read confirmation to the sender of this message.",
     "Could not send mdn" : "Could not send mdn",
+    "Forward" : "فرستادن",
     "Move message" : "Move message",
+    "Translate" : "ترجمه",
     "Forward message as attachment" : "Forward message as attachment",
     "View source" : "View source",
     "Download thread data for debugging" : "Download thread data for debugging",
@@ -371,6 +380,8 @@ OC.L10N.register(
     "Add" : "افزودن",
     "Copied email address to clipboard" : "Copied email address to clipboard",
     "Could not copy email address to clipboard" : "Could not copy email address to clipboard",
+    "Show less" : "Show less",
+    "Show more" : "Show more",
     "Search in mailbox" : "Search in mailbox",
     "Close" : "بسته",
     "Search parameters" : "Search parameters",
@@ -442,6 +453,16 @@ OC.L10N.register(
     "Go to latest message" : "Go to latest message",
     "Go to newest message" : "Go to newest message",
     "{name} Assistant" : "{name} Assistant",
+    "Translate message" : "Translate message",
+    "Source language to translate from" : "Source language to translate from",
+    "Translate from" : "Translate from",
+    "Target language to translate into" : "Target language to translate into",
+    "Translate to" : "Translate to",
+    "Translating" : "Translating",
+    "Copy translated text" : "رونوشت متن ترجمه",
+    "The message could not be translated" : "The message could not be translated",
+    "Translation copied to clipboard" : "Translation copied to clipboard",
+    "Translation could not be copied" : "Translation could not be copied",
     "Disable trash retention by leaving the field empty or setting it to 0. Only mails deleted after enabling trash retention will be processed." : "Disable trash retention by leaving the field empty or setting it to 0. Only mails deleted after enabling trash retention will be processed.",
     "No senders are trusted at the moment." : "No senders are trusted at the moment.",
     "Could not remove trusted sender {sender}" : "Could not remove trusted sender {sender}",
@@ -593,7 +614,6 @@ OC.L10N.register(
     "The link leads to %s" : "پیوند منجر به%s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>.",
     "Continue to %s" : "ادامه دهید%s",
-    "Sieve filter rules" : "Sieve filter rules",
-    "Sieve filter server" : "Sieve filter server"
+    "Unselect" : "لغو انتخاب"
 },
 "nplurals=2; plural=(n > 1);");
