@@ -238,6 +238,7 @@ OC.L10N.register(
     "You sent a read confirmation to the sender of this message." : "Lähetit lukukuittauksen tämän viestin lähettäjälle.",
     "Forward" : "Lähetä edelleen",
     "Move message" : "Siirrä viesti",
+    "Translate" : "Käännä",
     "Forward message as attachment" : "Välitä viesti liitteenä",
     "View source" : "Näytä lähde",
     "Download thread data for debugging" : "Lataa ketjun data vianjäljitystä varten",
@@ -331,6 +332,8 @@ OC.L10N.register(
     "Add" : "Lisää",
     "Copied email address to clipboard" : "Sähköpostiosoite kopioitu leikepöydälle",
     "Could not copy email address to clipboard" : "Sähköpostiosoitetta ei voitu kopioida leikepöydälle",
+    "Show less" : "Näytä vähemmän",
+    "Show more" : "Näytä enemmän",
     "Close" : "Sulje",
     "Body" : "Sisältö",
     "Date" : "Päivä",
@@ -378,6 +381,16 @@ OC.L10N.register(
     "Signature verified" : "Allekirjoitus vahvistettu",
     "Signature unverified " : "Allekirjoitus vahvistamatta",
     "This message was encrypted by the sender before it was sent." : "Tämän viestin lähettäjä salasi viestin ennen sen lähettämistä.",
+    "Translate message" : "Käännä viesti",
+    "Source language to translate from" : "Lähdekieli, josta käännetään",
+    "Translate from" : "Lähdekieli",
+    "Target language to translate into" : "Kohdekieli, jolle käännetään",
+    "Translate to" : "Kohdekieli",
+    "Translating" : "Käännetään",
+    "Copy translated text" : "Kopioi käännetty teksti",
+    "The message could not be translated" : "Viestiä ei voitu kääntää",
+    "Translation copied to clipboard" : "Käännös kopioitu leikepöydälle",
+    "Translation could not be copied" : "Käännöstä ei voitu kopioida",
     "No senders are trusted at the moment." : "Ei luotettuja lähettäjiä tällä hetkellä.",
     "Could not remove trusted sender {sender}" : "Ei voitu poistaa luotettua lähettäjää {sender}",
     "(organizer)" : "(järjestäjä)",
@@ -392,6 +405,7 @@ OC.L10N.register(
     "Train from {depStation} to {arrStation}" : "Juna asemalta {depStation} asemalle {arrStation}",
     "Flag" : "Lippu",
     "Operator" : "Operaattori",
+    "Filter name" : "Nimisuodatin",
     "Actions" : "Toiminnot",
     "New action" : "Uusi toiminto",
     "Priority" : "Tärkeys",
@@ -483,8 +497,6 @@ OC.L10N.register(
     "Redirect" : "Uudelleenohjaus",
     "The link leads to %s" : "Tämä linkki johtaa kohteeseen %s",
     "Continue to %s" : "Jatka sivulle %s",
-    "Sieve filter rules" : "Sieve-filtterin säännöt",
-    "Sieve filter server" : "Sieve-filtteripalvelin",
     "Unselect" : "Poista valinta"
 },
 "nplurals=2; plural=(n != 1);");
