@@ -115,8 +115,6 @@ OC.L10N.register(
     "Read" : "Čitaj",
     "Mark not spam" : "Označi da nije neželjena pošta",
     "Mark as spam" : "Označi kao neželjenu poštu",
-    "Unselect" : "Poništi odabir",
-    "Select" : "Odaberi",
     "Edit tags" : "Uredi oznake",
     "Move thread" : "Premjesti dretvu",
     "Delete thread" : "Izbriši dretvu",
@@ -128,14 +126,23 @@ OC.L10N.register(
     "Blind copy recipients only" : "Samo primatelji skrivenih kopija poruke",
     "No trash mailbox configured" : "Nije konfiguriran sandučić za izbrisanu poštu",
     "Could not delete message" : "Brisanje poruke nije uspjelo",
-    "Forward" : "Naprijed",
     "Load more" : "Učitaj više",
+    "_Mark {number} read_::_Mark {number} read_" : ["Označi {number} kao pročitano","Označi {number} kao pročitano","Označi {number} kao pročitano"],
+    "_Mark {number} unread_::_Mark {number} unread_" : ["Označi {number} kao nepročitano","Označi {number} kao nepročitano","Označi {number} kao nepročitano"],
+    "_Mark {number} as important_::_Mark {number} as important_" : ["Označi {number} kao važan","Označi {number} kao važan","Označi {number} kao važan"],
+    "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["Označi {number} kao nevažan","Označi {number} kao nevažan","Označi {number} kao nevažan"],
+    "_Unfavorite {number}_::_Unfavorite {number}_" : ["Ukloni {number} iz favorita","Ukloni {number} iz favorita","Ukloni {number} iz favorita"],
+    "_Favorite {number}_::_Favorite {number}_" : ["Dodaj {number} u favorite","Dodaj {number} u favorite","Dodaj {number} u favorite"],
+    "_Unselect {number}_::_Unselect {number}_" : ["Poništi odabir {number}","Poništi odabir {number}","Poništi odabir {number}"],
+    "_Move {number} thread_::_Move {number} threads_" : ["Premjesti {number} dretvu","Premjesti {number} dretve","Premjesti {number} dretvi"],
+    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Proslijedi {number} kao privitak","Proslijedi {number} kao privitak","Proslijedi {number} kao privitak"],
     "Report this bug" : "Prijavi ovu pogrešku",
     "All day" : "Cijeli dan",
     "Description" : "Opis",
     "Create" : "Stvori",
     "Event created" : "Događaj je stvoren",
     "Could not create event" : "Nije moguće stvoriti događaj",
+    "Select" : "Odaberi",
     "Comment" : "Komentar",
     "Accept" : "Prihvati",
     "Decline" : "Odbij",
@@ -156,7 +163,9 @@ OC.L10N.register(
     "Notify the sender" : "Obavijestite pošiljatelja",
     "You sent a read confirmation to the sender of this message." : "Poslali ste potvrdu o čitanju pošiljatelju ove poruke.",
     "Could not send mdn" : "Nije moguće poslati mdn",
+    "Forward" : "Naprijed",
     "Move message" : "Premjesti poruku",
+    "Translate" : "Prevedi",
     "View source" : "Vidi izvor",
     "Download thread data for debugging" : "Preuzmi podatke o dretvi radi otklanjanje pogrešaka",
     "Message body" : "Tijelo poruke",
@@ -227,6 +236,8 @@ OC.L10N.register(
     "Copy to clipboard" : "Kopiraj u međuspremnik",
     "Contact name …" : "Naziv kontakta…",
     "Add" : "Dodaj",
+    "Show less" : "Prikaži manje",
+    "Show more" : "Prikaži više",
     "Close" : "Zatvori",
     "Body" : "Tijelo",
     "Date" : "Datum",
@@ -367,7 +378,6 @@ OC.L10N.register(
     "Redirect" : "Preusmjeri",
     "The link leads to %s" : "Ova poveznica vodi do %s",
     "Continue to %s" : "Idi do %s",
-    "Sieve filter rules" : "Pravila filtra Sieve",
-    "Sieve filter server" : "Poslužitelj filtra Sieve"
+    "Unselect" : "Poništi odabir"
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
