@@ -101,8 +101,6 @@ OC.L10N.register(
     "Read" : "Lesa",
     "Mark not spam" : "Merkja sem ekki-ruslpóst",
     "Mark as spam" : "Merkja sem ruslpóst",
-    "Unselect" : "Afvelja",
-    "Select" : "Velja",
     "Edit tags" : "Breyta merkjum",
     "More actions" : "Fleiri aðgerðir",
     "Back" : "Til baka",
@@ -112,13 +110,13 @@ OC.L10N.register(
     "Blind copy recipients only" : "Einungis viðtakendur dulinna afrita",
     "No trash mailbox configured" : "Ekkert ruslpósthólf er stillt",
     "Could not delete message" : "Gat ekki eytt skilaboðum",
-    "Forward" : "Áframsenda",
     "Load more" : "Hlaða inn meira",
     "Report this bug" : "Tilkynna þessa villu",
     "All day" : "Heilsdagsviðburður",
     "Description" : "Lýsing",
     "Create" : "Búa til",
     "Could not create event" : "Tókst ekki að útbúa atburð",
+    "Select" : "Velja",
     "Comment" : "Athugasemd",
     "Accept" : "Samþykkja",
     "Decline" : "Hafna",
@@ -129,6 +127,8 @@ OC.L10N.register(
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "Geri atriðaskrá yfir skilaboðin þín. Þetta getur tekið drjúga stund fyrir stór pósthólf.",
     "Important info" : "Mikilvægar upplýsingar",
     "Other" : "Annað",
+    "Forward" : "Áframsenda",
+    "Translate" : "Þýða",
     "View source" : "Skoða frumkóða",
     "Choose a folder to store the attachment in" : "Veldu möppu þar sem á að geyma viðhengið",
     "Import into calendar" : "Flytja inn dagatal",
@@ -191,6 +191,7 @@ OC.L10N.register(
     "Mark as unread" : "Merkja allt sem ólesið",
     "Mark as read" : "Merkja sem lesið",
     "Message source" : "Uppruni skilaboða",
+    "Translate from" : "Þýða úr",
     "(organizer)" : "(skipuleggjandi)",
     "Untitled event" : "Ónefndur atburður",
     "Import into {calendar}" : "Flytja inn í {calendar}",
@@ -250,6 +251,7 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Smelltu hér ef þér er ekki beint áfram innan nokkurra sekúndna.",
     "Redirect" : "Endurbeina",
     "The link leads to %s" : "Tengillinn leiðir til %s",
-    "Continue to %s" : "Halda áfram í %s"
+    "Continue to %s" : "Halda áfram í %s",
+    "Unselect" : "Afvelja"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
