@@ -64,6 +64,7 @@ OC.L10N.register(
     "Preferred writing mode for new messages and replies." : "Pageidaujama rašymo veiksena naujuose laiškuose ir atsakant į laiškus.",
     "Default folders" : "Numatytieji aplankai",
     "Autoresponder" : "Atsakiklis",
+    "Filters" : "Filtrai",
     "Mail server" : "Pašto serveris",
     "Go back" : "Grįžti",
     "Change name" : "Keisti vardą",
@@ -156,8 +157,6 @@ OC.L10N.register(
     "Unfavorite" : "Nebežymėti kaip mėgstamą",
     "Favorite" : "Mėgstamas",
     "Read" : "Skaityti",
-    "Unselect" : "Nuimti žymėjimą",
-    "Select" : "Pasirinkti",
     "Edit tags" : "Redaguoti žymes",
     "Move thread" : "Perkelti giją",
     "Archive thread" : "Archyvuoti giją",
@@ -175,8 +174,9 @@ OC.L10N.register(
     "Set reminder for next week" : "Nustatyti priminimą kitą savaitę",
     "Could not delete message" : "Nepavyko ištrinti laiško",
     "Could not archive message" : "Nepavyko archyvuoti laiško",
-    "Forward" : "Persiųsti",
     "Load more" : "Įkelti daugiau",
+    "_Mark {number} read_::_Mark {number} read_" : ["Žymėti {number} kaip skaitytą","Žymėti {number} kaip skaitytus","Žymėti {number} kaip skaitytus","Žymėti {number} kaip skaitytą"],
+    "_Mark {number} unread_::_Mark {number} unread_" : ["Žymėti {number} kaip neskaitytą","Žymėti {number} kaip neskaitytus","Žymėti {number} kaip neskaitytus","Žymėti {number} kaip neskaitytą"],
     "Report this bug" : "Pranešti apie šią klaidą",
     "All day" : "Visą dieną",
     "Description" : "Aprašas",
@@ -184,6 +184,7 @@ OC.L10N.register(
     "Event created" : "Įvykis sukurtas",
     "Could not create event" : "Nepavyko sukurti įvykio",
     "Save to" : "Įrašyti į",
+    "Select" : "Pasirinkti",
     "Comment" : "Komentaras",
     "Accept" : "Priimti",
     "Decline" : "Atmesti",
@@ -205,7 +206,9 @@ OC.L10N.register(
     "The sender of this message has asked to be notified when you read this message." : "Šio laiško siuntėjas paprašė, kad jam būtų pranešta, kai perskaitysite šį laišką.",
     "Notify the sender" : "Pranešti siuntėjui",
     "You sent a read confirmation to the sender of this message." : "Jūs išsiuntėte šio laiško siuntėjui patvirtinimą, kad perskaitėte jo laišką.",
+    "Forward" : "Persiųsti",
     "Move message" : "Perkelti laišką",
+    "Translate" : "Verskite",
     "Forward message as attachment" : "Persiųsti laišką kaip priedą",
     "Message body" : "Pagrindinė laiško dalis",
     "Choose a folder to store the attachment in" : "Pasirinkite aplanką, kuriame išsaugoti priedą",
@@ -292,6 +295,8 @@ OC.L10N.register(
     "Add" : "Pridėti",
     "Copied email address to clipboard" : "El. pašto adresas nukopijuotas į iškarpinę",
     "Could not copy email address to clipboard" : "Nepavyko nukopijuoti el. pašto adreso į iškarpinę",
+    "Show less" : "Rodyti mažiau",
+    "Show more" : "Rodyti daugiau",
     "Search in mailbox" : "Ieškoti pašto dėžutėje",
     "Close" : "Užverti",
     "Date" : "Data",
@@ -311,7 +316,10 @@ OC.L10N.register(
     "Tag already exists" : "Žymė jau yra",
     "Tag name cannot be empty" : "Žymės pavadinimas negali būti tuščias",
     "An error occurred, unable to create the tag." : "Įvyko klaida, nepavyko sukurti žymės.",
+    "Task created" : "Užduotis sukurta",
+    "Could not create task" : "Nepavyko sukurti užduoties",
     "Not found" : "Nerasta",
+    "Disable reminder" : "Išjungti priminimą",
     "Unsubscribe" : "Atsisakyti prenumeratos",
     "Reply all" : "Atsakyti visiems",
     "Reply to sender only" : "Atsakyti tik siuntėjui",
@@ -429,6 +437,6 @@ OC.L10N.register(
     "Redirect" : "Peradresuoti",
     "The link leads to %s" : "Nuoroda veda į %s",
     "Continue to %s" : "Tęsti į %s",
-    "Account creation" : "Paskyros sukūrimas"
+    "Unselect" : "Nuimti žymėjimą"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
