@@ -61,16 +61,14 @@ OC.L10N.register(
     "Confirm" : "Apstiprināt",
     "Favorite" : "Izlasē",
     "Read" : "Lasīt",
-    "Unselect" : "Noņemt atlasi",
-    "Select" : "Atzīmēt",
     "Edit tags" : "Labot birkas",
     "Back" : "Atpakaļ",
     "Create event" : "Izveidot notikumu",
-    "Forward" : "Turpināt",
     "Load more" : "Ielādēt vairāk",
     "All day" : "Visas dienas",
     "Description" : "Apraksts",
     "Create" : "Izveidot",
+    "Select" : "Atzīmēt",
     "Comment" : "Piebilde",
     "Accept" : "Pieņemt",
     "Decline" : "Noraidīt",
@@ -78,6 +76,8 @@ OC.L10N.register(
     "Remove" : "Noņemt",
     "email" : "e-pasts",
     "Other" : "Cits",
+    "Forward" : "Turpināt",
+    "Translate" : "Tulkot",
     "View source" : "Skatīt avotu",
     "Choose a folder to store the attachment in" : "Izvēlieties mapi, kurā saglabāt pielikumus",
     "Import into calendar" : "Importēt kalendārā",
@@ -102,6 +102,7 @@ OC.L10N.register(
     "Message" : "Ziņojums",
     "Copy to clipboard" : "Kopēt starpliktuvē",
     "Add" : "Pievienot",
+    "Show more" : "Parādīt vairāk",
     "Search in mailbox" : "Meklēt pastkastē",
     "Close" : "Aizvērt",
     "Date" : "Datums",
@@ -140,9 +141,10 @@ OC.L10N.register(
     "There was a problem loading {tag}{name}{endtag}" : "Radusies problēma, ielādējot {tag}{name}{endtag}",
     "Error loading message" : "Kļūda ielādējot vēstuli",
     "Forwarding to %s" : "Pārsūtīt uz %s",
-    "Click here if you are not automatically redirected within the next few seconds." : "Noklikšķiniet šeit, ja netiekat pārvirzīts automātiski dažu sekunžu laikā.",
+    "Click here if you are not automatically redirected within the next few seconds." : "Jāklikšķina šeit, ja nenotiek automātiska pārvirzīšana dažu sekunžu laikā.",
     "Redirect" : "Novirzīt",
     "The link leads to %s" : "Saite, kas ved uz %s",
-    "Continue to %s" : "Turpināt %s"
+    "Continue to %s" : "Turpināt %s",
+    "Unselect" : "Noņemt atlasi"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
