@@ -169,8 +169,6 @@ OC.L10N.register(
     "Unimportant" : "Неважна",
     "Mark not spam" : "Од-означи СПАМ",
     "Mark as spam" : "Означи како СПАМ",
-    "Unselect" : "Поништи избор",
-    "Select" : "Select",
     "Edit tags" : "Удери ознаки",
     "More actions" : "Повеќе акции",
     "Back" : "Назад",
@@ -186,8 +184,13 @@ OC.L10N.register(
     "Set reminder for next week" : "Постави потсетник за наредната недела",
     "No trash mailbox configured" : "Нема конфигурирано сандаче за отпадоци",
     "Could not delete message" : "Неможе да се избрише пораката",
-    "Forward" : "Препрати",
     "Load more" : "Вчитај повеќе",
+    "_Mark {number} read_::_Mark {number} read_" : ["Означи {number} прочитана","Означи {number} прочитани"],
+    "_Mark {number} unread_::_Mark {number} unread_" : ["Означи {number} непрочитана","Означи {number} непрочитани"],
+    "_Mark {number} as important_::_Mark {number} as important_" : ["Означи {number} како важна","Означи {number} како важни"],
+    "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["Означи {number} како неважна","Означи {number} како неважни"],
+    "_Unselect {number}_::_Unselect {number}_" : ["Од-означи {number}","Од-означи {number}"],
+    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Препрати како прилог","Препрати {number} како прилозиt"],
     "Report this bug" : "Пријави грешка",
     "All day" : "Цели денови",
     "Select calendar" : "Избери календар",
@@ -197,6 +200,7 @@ OC.L10N.register(
     "You have been invited to an event" : "Поканети сте на настан",
     "This event was cancelled" : "Овој настан беше откажан",
     "Save to" : "Зачувај во",
+    "Select" : "Select",
     "Comment" : "Коментар",
     "Accept" : "Прифати",
     "Decline" : "Одбиј",
@@ -220,7 +224,9 @@ OC.L10N.register(
     "The sender of this message has asked to be notified when you read this message." : "Испраќачот на оваа порака посака да биде известен кога ќе ја прочитате оваа порака.",
     "Notify the sender" : "Извести го испраќачот",
     "You sent a read confirmation to the sender of this message." : "Испративте потврда до испраќачот дека е прочитана пораката.",
+    "Forward" : "Препрати",
     "Move message" : "Премести порака",
+    "Translate" : "Преведи",
     "Forward message as attachment" : "Препрати ја пораката како прилог",
     "View source" : "Погледни извор",
     "Download thread data for debugging" : "Преземи информации за развивачи",
@@ -307,6 +313,8 @@ OC.L10N.register(
     "Copy to clipboard" : "Копирај во клипборд",
     "Contact name …" : "Име на контакт ...",
     "Add" : "Додади",
+    "Show less" : "Помалку",
+    "Show more" : "Прикажи повеќе",
     "Search in mailbox" : "Барај во сандачето",
     "Close" : "Затвори",
     "Search parameters" : "Параметри за пребарување",
@@ -424,6 +432,7 @@ OC.L10N.register(
     "Redirect" : "Пренасочи",
     "The link leads to %s" : "Линкот води кон %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Доколку несакате да ја посетите страната, можете да се вратите кон <a href=\"%s\">Е-пошта</a>.",
-    "Continue to %s" : "Продолжи до %s"
+    "Continue to %s" : "Продолжи до %s",
+    "Unselect" : "Поништи избор"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
