@@ -12,7 +12,11 @@ OC.L10N.register(
     "To Do" : "Te doen",
     "Later" : "Later",
     "Mail" : "E-mail",
+    "You are reaching your mailbox quota limit for {account_email}" : "Je nadert je mailbox-quotumlimiet voor {account_email}",
+    "You are currently using {percentage} of your mailbox storage. Please make some space by deleting unneeded emails." : "Je gebruikt momenteel {percentage} van je mailbox-opslag. Gelieve ruimte vrij te maken door onnodige mails te verwijderen.",
     "Mails" : "Mails",
+    "Sent date is in the future" : "Verzenddatum ligt in de toekomst",
+    "Some addresses in this message are not matching the link text" : "Sommige adressen in dit bericht komen niet overeen met de linktekst",
     "💌 A mail app for Nextcloud" : "💌 Een e-mail app voor Nextcloud",
     "Drafts are saved in:" : "Concepten worden opgeslagen in:",
     "Sent messages are saved in:" : "Verzonden berichten worden opgeslagen in:",
@@ -123,8 +127,6 @@ OC.L10N.register(
     "Unimportant" : "Onbelangrijk",
     "Mark not spam" : "Markeer als geen-spam",
     "Mark as spam" : "Markeren als spam",
-    "Unselect" : "Deselecteren",
-    "Select" : "Selecteer",
     "Edit tags" : "Bewerken tags",
     "Move thread" : "Verplaats draadje",
     "Delete thread" : "Verwijder draadje",
@@ -134,16 +136,29 @@ OC.L10N.register(
     "Create event" : "Creëer afspraak",
     "Create task" : "Aanmaken taak",
     "Blind copy recipients only" : "Alleen ontvangers van blinde kopie",
+    "Set reminder for later today" : "Herinnering voor later vandaag instellen",
+    "Set reminder for tomorrow" : "Herinnering voor morgen instellen",
+    "Set reminder for this weekend" : "Herinnering voor het weekend instellen",
+    "Set reminder for next week" : "Herinnering instellen voor volgende week",
     "No trash mailbox configured" : "Geen verwijderde berichtenmap ingesteld",
     "Could not delete message" : "Kon bericht niet verwijderen",
-    "Forward" : "Doorsturen",
     "Load more" : "Laad meer",
+    "_Mark {number} read_::_Mark {number} read_" : ["Markeren {number} als gelezen","Markeren {number} als gelezen"],
+    "_Mark {number} unread_::_Mark {number} unread_" : ["Markeer {number} ongelezen","Markeer {number} ongelezen"],
+    "_Mark {number} as important_::_Mark {number} as important_" : ["Markeer {number} als niet belangrijk","Markeer {number} als belangrijk"],
+    "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["Markeer {number} als niet belangrijk","Mark {number} as unimportant"],
+    "_Unfavorite {number}_::_Unfavorite {number}_" : ["Favoriet weghalen {number}","Favoriet weghalen {number}"],
+    "_Favorite {number}_::_Favorite {number}_" : ["Favoriet maken {number}","Favoriet maken {number}"],
+    "_Unselect {number}_::_Unselect {number}_" : ["De-selecteren {number}","De-selecteren {number}"],
+    "_Move {number} thread_::_Move {number} threads_" : ["Verplaatsen {number} draadje","Verplaatsen {number} draadjes"],
+    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Doorsturen {number} als bijlage","Doorsturen {number} als bijlage"],
     "Report this bug" : "Meld deze fout",
     "All day" : "Alle dagen",
     "Description" : "Omschrijving",
     "Create" : "Aanmaken",
     "Event created" : "Afspraak aangemaakt",
     "Could not create event" : "Kon afspraak niet creëren",
+    "Select" : "Selecteer",
     "Comment" : "Notitie",
     "Accept" : "Accepteren",
     "Decline" : "Afwijzen",
@@ -164,7 +179,9 @@ OC.L10N.register(
     "Notify the sender" : "Informeer de afzender",
     "You sent a read confirmation to the sender of this message." : "Je hebt een leesbevestiging aan de afzender van dit bericht gestuurd.",
     "Could not send mdn" : "Kon mdn niet versturen",
+    "Forward" : "Doorsturen",
     "Move message" : "Verplaats bericht",
+    "Translate" : "Vertaal",
     "View source" : "Bekijk bron",
     "Download thread data for debugging" : "Download draadgegevens voor debuggen",
     "Message body" : "Berichttekst",
@@ -225,6 +242,7 @@ OC.L10N.register(
     "Sending …" : "Versturen ...",
     "Warning sending your message" : "Waarschuwing bij het versturen van jouw bericht",
     "Send anyway" : "Toch verzenden",
+    "Edit message" : "Bewerk bericht",
     "Draft" : "Concept",
     "Reply" : "Antwoord",
     "No sent mailbox configured. Please pick one in the account settings." : "Er is geen map voor verzonden berichten ingesteld. Kies er een in de accountinstellingen.",
@@ -237,6 +255,8 @@ OC.L10N.register(
     "Copy to clipboard" : "Kopiëren naar het klembord",
     "Contact name …" : "Naam contactpersoon ...",
     "Add" : "Toevoegen",
+    "Show less" : "Toon minder",
+    "Show more" : "Toon meer",
     "Close" : "Sluit",
     "Body" : "Body",
     "Date" : "Datum",
@@ -270,6 +290,16 @@ OC.L10N.register(
     "Mark as read" : "Markeren als gelezen",
     "Delete message" : "Bericht verwijderen",
     "Message source" : "Bericht brontekst",
+    "Translate message" : "Vertaal bericht",
+    "Source language to translate from" : "Brontaal om vanuit te vertalen",
+    "Translate from" : "Vertaal vanuit",
+    "Target language to translate into" : "Doeltaal om naar te vertalen",
+    "Translate to" : "Vertaal naar",
+    "Translating" : "Vertalen",
+    "Copy translated text" : "Kopieer vertaalde tekst",
+    "The message could not be translated" : "Het bericht kon niet vertaald worden",
+    "Translation copied to clipboard" : "Vertaling gekopieerd naar klembord",
+    "Translation could not be copied" : "Vertaling kon niet gekopieerd worden",
     "No senders are trusted at the moment." : "Er zijn nu geen vertrouwder afzenders.",
     "Could not remove trusted sender {sender}" : "Kon vertrouwde afzender niet verwijderen {afzender}",
     "(organizer)" : "(organisator)",
@@ -387,7 +417,6 @@ OC.L10N.register(
     "Redirect" : "Omleiden",
     "The link leads to %s" : "De link verwijst naar %s",
     "Continue to %s" : "Verder naar %s",
-    "Sieve filter rules" : "Sieve filterregels",
-    "Sieve filter server" : "Sieve filterserver"
+    "Unselect" : "Deselecteren"
 },
 "nplurals=2; plural=(n != 1);");
