@@ -58,6 +58,7 @@ OC.L10N.register(
     "Decline" : "Declinar",
     "Remove" : "Suprimir",
     "Other" : "Autre",
+    "Translate" : "Tradurre",
     "Choose a folder to store the attachment in" : "Causissètz lo dorsièr dins lo qual enregistrar la pèça junta",
     "Move" : "Move",
     "Quota" : "Quota",
@@ -79,6 +80,8 @@ OC.L10N.register(
     "Custom" : "Personalizats",
     "Mark as unread" : "Marcar coma pas legit",
     "Mark as read" : "Marcar coma legit",
+    "Translate message" : "Traduire lo messatge",
+    "Translating" : "Traduccion",
     "Untitled event" : "Eveniment sens títol",
     "Train" : "Tren",
     "Flag" : "Drapèu",
