@@ -183,8 +183,6 @@ OC.L10N.register(
     "Unimportant" : "Nieważne",
     "Mark not spam" : "Nie spam",
     "Mark as spam" : "Oznacz jako spam",
-    "Unselect" : "Odznacz",
-    "Select" : "Zaznacz",
     "Edit tags" : "Edytuj etykiety",
     "Move thread" : "Przenieś wątek",
     "Archive thread" : "Wątek archiwalny",
@@ -204,8 +202,17 @@ OC.L10N.register(
     "No trash mailbox configured" : "Nie skonfigurowano skrzynki pocztowej dla kosza",
     "Could not delete message" : "Nie udało się usunąć wiadomości",
     "Could not archive message" : "Nie udało się zarchiwizować wiadomości",
-    "Forward" : "Przekaż dalej",
     "Load more" : "Wczytaj więcej",
+    "_Mark {number} read_::_Mark {number} read_" : ["Oznacz {number} jako przeczytana","Oznacz {number} jako przeczytane","Oznacz {number} jako przeczytane","Oznacz {number} jako przeczytane"],
+    "_Mark {number} unread_::_Mark {number} unread_" : ["Oznacz {number} jako nieprzeczytana","Oznacz {number} jako nieprzeczytane","Oznacz {number} jako nieprzeczytane","Oznacz {number} jako nieprzeczytane"],
+    "_Mark {number} as important_::_Mark {number} as important_" : ["Oznacz {number} jako ważne","Oznacz {number} jako ważne","Oznacz {number} jako ważne","Oznacz {number} jako ważne"],
+    "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["Oznacz {number} jako nieważne","Oznacz {number} jako nieważne","Oznacz {number} jako nieważne","Oznacz {number} jako nieważne"],
+    "_Unfavorite {number}_::_Unfavorite {number}_" : ["Nie ulubiona {number}","Nie ulubione {number}","Nie ulubionych {number}","Nie ulubionych {number}"],
+    "_Favorite {number}_::_Favorite {number}_" : ["Ulubiona {number}","Ulubione {number}","Ulubionych {number}","Ulubionych {number}"],
+    "_Unselect {number}_::_Unselect {number}_" : ["Odznacz {number}","Odznacz {number}","Odznacz {number}","Odznacz {number}"],
+    "_Mark {number} as spam_::_Mark {number} as spam_" : ["Oznacz {numer} jako spam","Oznacz {numer} jako spam","Oznacz {numer} jako spam","Oznacz {numer} jako spam"],
+    "_Move {number} thread_::_Move {number} threads_" : ["Przenieś {number} wątek","Przenieś {number} wątki","Przenieś {number} wątków","Przenieś {number} wątków"],
+    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Przekaż {number} jako załącznik","Przekaż {number} jako załączniki","Przekaż {number} jako załączniki","Przekaż {number} jako załączniki"],
     "Report this bug" : "Zgłoś ten błąd",
     "All day" : "Cały dzień",
     "Select calendar" : "Wybierz kalendarz",
@@ -220,6 +227,7 @@ OC.L10N.register(
     "You have been invited to an event" : "Zostałeś zaproszony na wydarzenie",
     "This event was cancelled" : "Wydarzenie te zostało odwołane",
     "Save to" : "Zapisz w",
+    "Select" : "Zaznacz",
     "Comment" : "Komentarz",
     "Accept" : "Akceptuj",
     "Decline" : "Odrzuć",
@@ -249,7 +257,9 @@ OC.L10N.register(
     "Notify the sender" : "Powiadom nadawcę",
     "You sent a read confirmation to the sender of this message." : "Wysłałeś potwierdzenie do nadawcy o przeczytaniu tej wiadomości.",
     "Could not send mdn" : "Nie można wysłać mdn",
+    "Forward" : "Przekaż dalej",
     "Move message" : "Przenieś wiadomość",
+    "Translate" : "Tłumaczenie",
     "Forward message as attachment" : "Wyślij wiadomość jako załącznik",
     "View source" : "Pokaż źródło",
     "Download thread data for debugging" : "Pobierz dane wątku do debugowania",
@@ -345,6 +355,8 @@ OC.L10N.register(
     "Add" : "Dodaj",
     "Copied email address to clipboard" : "Skopiowano adres e-mail do schowka",
     "Could not copy email address to clipboard" : "Nie można skopiować adresu e-mail do schowka",
+    "Show less" : "Pokaż mniej",
+    "Show more" : "Pokaż więcej",
     "Search in mailbox" : "Szukaj w skrzynce pocztowej",
     "Close" : "Zamknij",
     "Search parameters" : "Wyszukaj parametry",
@@ -394,6 +406,16 @@ OC.L10N.register(
     "Message source" : "Źródło wiadomości",
     "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "Ta wiadomość zawiera zweryfikowany podpis cyfrowy S/MIME. Wiadomość nie została zmieniona od czasu jej wysłania.",
     "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "Ta wiadomość zawiera niezweryfikowany cyfrowy podpis S/MIME. Wiadomość mogła zostać zmieniona od czasu jej wysłania lub certyfikat osoby podpisującej jest niezaufany.",
+    "Translate message" : "Przetłumacz wiadomość",
+    "Source language to translate from" : "Język źródłowy, z którego chcesz tłumaczyć",
+    "Translate from" : "Przetłumacz z",
+    "Target language to translate into" : "Język docelowy, na który chcesz tłumaczyć",
+    "Translate to" : "Przetłumacz na",
+    "Translating" : "Tłumaczenie",
+    "Copy translated text" : "Kopiuj przetłumaczony tekst",
+    "The message could not be translated" : "Nie udało się przetłumaczyć wiadomości",
+    "Translation copied to clipboard" : "Tłumaczenie skopiowane do schowka",
+    "Translation could not be copied" : "Nie można skopiować tłumaczenia",
     "No senders are trusted at the moment." : "W tej chwili żaden nadawca nie jest zaufany.",
     "Could not remove trusted sender {sender}" : "Nie udało się usunąć zaufanego nadawcy {sender}",
     "(organizer)" : "(organizator)",
@@ -540,8 +562,6 @@ OC.L10N.register(
     "The link leads to %s" : "Link prowadzi do %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Jeśli nie chcesz odwiedzić tej strony, możesz powrócić do <a href=\"%s\">Poczty</a>.",
     "Continue to %s" : "Kontynuuj do %s",
-    "Sieve filter rules" : "Zasady filtra Sieve",
-    "Sieve filter server" : "Serwer filtra Sieve",
-    "Account creation" : "Tworzenie konta"
+    "Unselect" : "Odznacz"
 },
 "nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
