@@ -35,7 +35,9 @@ OC.L10N.register(
     "SMTP Port" : "Porto SMTP",
     "SMTP User" : "Utilizador SMTP",
     "SMTP Password" : "Palavra-passe SMTP",
-    "Connecting" : "A conectar",
+    "Connecting" : "A ligar",
+    "Reconnect Google account" : "Religar conta Google",
+    "Reconnect Microsoft account" : "Religar conta Microsoft",
     "Save" : "Guardar",
     "Connect" : "Ligar",
     "Password required" : "Necessário palavra-passe",
@@ -91,20 +93,19 @@ OC.L10N.register(
     "Favorite" : "Favorito",
     "Read" : "Ler",
     "Mark as spam" : "Marcar como spam",
-    "Unselect" : "Não selecionar",
-    "Select" : "Seleccionar",
     "Edit tags" : "Editar etiquetas",
     "More actions" : "Mais acções",
     "Back" : "Anterior",
     "Edit as new message" : "Editar como nova mensagem",
     "Create event" : "Criar evento",
+    "Download message" : "Transferir mensagem",
     "Could not delete message" : "Não foi possível apagar a mensagem",
-    "Forward" : "Encaminhar",
     "Load more" : "Carregar mais",
     "All day" : "Todo o dia",
     "Description" : "Descrição",
     "Create" : "Criar",
     "Could not create event" : "Não foi possível criar o evento",
+    "Select" : "Seleccionar",
     "Comment" : "Comentário",
     "Accept" : "Aceitar",
     "Decline" : "Recusar",
@@ -115,6 +116,8 @@ OC.L10N.register(
     "Important info" : "Informação importante",
     "Other" : "Outro",
     "Notify the sender" : "Notificar o remetente",
+    "Forward" : "Encaminhar",
+    "Translate" : "Traduzir",
     "View source" : "Ver fonte",
     "Message body" : "Corpo da mensagem",
     "Choose a folder to store the attachment in" : "Escolha uma pasta para guardar o anexo",
@@ -222,6 +225,7 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Clique aqui se não for automaticamente redireccionado dentro de segundos.",
     "Redirect" : "Redirecionar",
     "The link leads to %s" : "A ligação aponta para %s",
-    "Continue to %s" : "Continuar para %s"
+    "Continue to %s" : "Continuar para %s",
+    "Unselect" : "Não selecionar"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
