@@ -111,8 +111,6 @@ OC.L10N.register(
     "Read" : "Leghe",
     "Mark not spam" : "Marca comente no spam",
     "Mark as spam" : "Marca comente spam",
-    "Unselect" : "Deseletziona",
-    "Select" : "Seletziona",
     "Edit tags" : "Modìfica etichetas",
     "Move thread" : "Tràmuda dibata",
     "Delete thread" : "Cantzella dibata",
@@ -128,13 +126,20 @@ OC.L10N.register(
     "Set reminder for next week" : "Cunfigura un'apuntu pro chida chi benit",
     "No trash mailbox configured" : "Peruna casella de àliga cunfigurada",
     "Could not delete message" : "No at fatu a cantzellare su messàgiu",
-    "Forward" : "Torra a imbiare",
     "Load more" : "Càrriga àteru",
+    "_Mark {number} read_::_Mark {number} read_" : ["Marca {number} lèghidos","Marca {number} lèghidos"],
+    "_Mark {number} unread_::_Mark {number} unread_" : ["Marca {number} no lèghidos","Marca {number} non lèghidos"],
+    "_Unfavorite {number}_::_Unfavorite {number}_" : ["Boga dae is preferidos {number}","Boga dae is preferidos {number}"],
+    "_Favorite {number}_::_Favorite {number}_" : ["Agiunghe a is preferidos","Agiunghe a is Preferidos {number}"],
+    "_Unselect {number}_::_Unselect {number}_" : ["Deseletziona {number}","Deseletziona {number}"],
+    "_Move {number} thread_::_Move {number} threads_" : ["Tràmuda {number} dibatas","Tràmuda {number} dibatas"],
+    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Inoltra {number} comente alligongiados","Inoltra {number} comente alligongiadu"],
     "Report this bug" : "Signala cust'errore",
     "All day" : "Totu sa die",
     "Description" : "Descritzione",
     "Create" : "Crea",
     "Could not create event" : "No at fatu a creare s'eventu",
+    "Select" : "Seletziona",
     "Comment" : "Cummentu",
     "Accept" : "Atzeta",
     "Decline" : "Refuda",
@@ -156,7 +161,9 @@ OC.L10N.register(
     "Notify the sender" : "Notificare a sa persone chi imbiat",
     "You sent a read confirmation to the sender of this message." : "As imbiadu una cunfirma de letura a sa persone chi at imbiadu custu messàgiu.",
     "Could not send mdn" : "No at fatu a imbiare mdn",
+    "Forward" : "Torra a imbiare",
     "Move message" : "Tràmuda messàgiu",
+    "Translate" : "Borta",
     "View source" : "Visualiza sa fonte",
     "Download thread data for debugging" : "Iscàrriga is datos de sa dibata pro sa curretzione",
     "Message body" : "Corpus de su messàgiu",
@@ -226,6 +233,8 @@ OC.L10N.register(
     "Copy to clipboard" : "Còpia in is punta de billete",
     "Contact name …" : "Nùmene de su cuntatu ...",
     "Add" : "Agiunghe",
+    "Show less" : "Mustra prus pagu",
+    "Show more" : "Mustra de prus",
     "Close" : "Serra",
     "Body" : "Corpus",
     "Date" : "Data",
@@ -349,7 +358,6 @@ OC.L10N.register(
     "Redirect" : "Torra a deretare",
     "The link leads to %s" : "Su ligòngiu deretat a %s",
     "Continue to %s" : "Sighi in %s",
-    "Sieve filter rules" : "Règulas de filtru Sieve",
-    "Sieve filter server" : "Serbidore de filtru Sieve"
+    "Unselect" : "Deseletziona"
 },
 "nplurals=2; plural=(n != 1);");
