@@ -20,15 +20,16 @@ OC.L10N.register(
     "Confirm" : "තහවුරු කරන්න",
     "Favorite" : "ප්‍රියතම",
     "Read" : "කියවීම",
-    "Select" : "තෝරන්න",
     "Back" : "ආපසු",
     "Description" : "විස්තරය",
     "Create" : "සාදන්න",
+    "Select" : "තෝරන්න",
     "Comment" : "අදහස",
     "Accept" : "පිළිගන්න",
     "Decline" : "ප්‍රතික්ෂේප",
     "Remove" : "ඉවත් කරන්න",
     "Other" : "වෙනත්",
+    "Translate" : "පරිවර්තනය",
     "Remove account" : "ගිණුම ඉවත් කරන්න",
     "Loading …" : "පූරණය වෙමින් …",
     "Mark all as read" : "සියල්ල කියවූ ලෙස සලකුණු කරන්න",
@@ -36,6 +37,7 @@ OC.L10N.register(
     "Reply" : "පිළිතුර",
     "Message" : "පණිවිඩය",
     "Add" : "එකතු කරන්න",
+    "Show more" : "තව පෙන්වන්න",
     "Close" : "වසන්න",
     "Body" : "අන්තර්ගතය",
     "Date" : "දිනය",
