@@ -137,8 +137,6 @@ OC.L10N.register(
     "Unimportant" : "Oviktigt",
     "Mark not spam" : "Markera som ej skräppost",
     "Mark as spam" : "Markera som skräppost",
-    "Unselect" : "Avmarkera",
-    "Select" : "Välj",
     "Edit tags" : "Redigera taggar",
     "Move thread" : "Flytta tråd",
     "Archive thread" : "Arkivera tråd",
@@ -157,14 +155,21 @@ OC.L10N.register(
     "No trash mailbox configured" : "Ingen skräpkorg är konfigurerad",
     "Could not delete message" : "Kunde inte radera meddelande",
     "Could not archive message" : "Kunde inte arkivera meddelandet",
-    "Forward" : "Vidarebefordra",
     "Load more" : "Ladda mer",
+    "_Mark {number} read_::_Mark {number} read_" : ["Markera {number} meddelande som läst","Markera {number} meddelanden som lästa"],
+    "_Mark {number} unread_::_Mark {number} unread_" : ["Markera {number} meddelande som oläst","Markera {number} meddelanden som olästa"],
+    "_Mark {number} as important_::_Mark {number} as important_" : ["Markera {number} meddelande som viktigt","Markera {number} meddelanden som viktiga"],
+    "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["Markera {number} meddelande som oviktigt","Markera {number} meddelanden som oviktiga"],
+    "_Unselect {number}_::_Unselect {number}_" : ["Avmarkera {number}","Avmarkera {number}"],
+    "_Move {number} thread_::_Move {number} threads_" : ["Flytta {number} tråd","Flytta {number} trådar"],
+    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Vidarebefordra {number} som bilaga","Vidarebefordra {number} som bilagor"],
     "Report this bug" : "Rapportera detta fel",
     "All day" : "Hela dagen",
     "Description" : "Beskrivning",
     "Create" : "Skapa",
     "Event created" : "Evenemang skapat",
     "Could not create event" : "Kunde inte skapa händelse",
+    "Select" : "Välj",
     "Comment" : "Kommentar",
     "Accept" : "Acceptera",
     "Decline" : "Avböj",
@@ -184,7 +189,9 @@ OC.L10N.register(
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Meddelanden kommer automatiskt att markeras som viktiga baserat på vilka meddelanden du interagerade med eller har markerat som viktiga. I början kan du behöva ändra vikten manuellt, men det kommer att förbättras med tiden.",
     "Notify the sender" : "Meddela avsändaren",
     "You sent a read confirmation to the sender of this message." : "Du har skickat ett läskvitto till meddelandets avsändare.",
+    "Forward" : "Vidarebefordra",
     "Move message" : "Flytta meddelande",
+    "Translate" : "Översätt",
     "Forward message as attachment" : "Vidarebefordra medelande som bilaga",
     "View source" : "Visa källa",
     "Message body" : "Meddelandetext",
@@ -254,6 +261,8 @@ OC.L10N.register(
     "Copy to clipboard" : "Kopiera till urklipp",
     "Contact name …" : "Kontaktnamn …",
     "Add" : "Lägg till",
+    "Show less" : "Visa mindre",
+    "Show more" : "Visa mer",
     "Search in mailbox" : "Sök i brevlådan",
     "Close" : "Stäng",
     "Search parameters" : "Sökparametrar",
@@ -286,6 +295,16 @@ OC.L10N.register(
     "Archive message" : "Arkivera meddelandet",
     "Delete message" : "Radera meddelande",
     "Message source" : "Meddelandekälla",
+    "Translate message" : "Översätt meddelande",
+    "Source language to translate from" : "Språk att översätta från",
+    "Translate from" : "Översätt från",
+    "Target language to translate into" : "Språk att översätta till",
+    "Translate to" : "Översätt till",
+    "Translating" : "Översätter",
+    "Copy translated text" : "Kopiera översatt text",
+    "The message could not be translated" : "Meddelandet kunde inte översättas",
+    "Translation copied to clipboard" : "Översättningen har kopierats till urklipp",
+    "Translation could not be copied" : "Översättningen kunde inte kopieras",
     "No senders are trusted at the moment." : "Inga avsändare är betrodda för tillfället.",
     "(organizer)" : "(arrangör)",
     "Untitled event" : "Namnlös händelse",
@@ -356,6 +375,7 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Klicka här om du inte blir omdirigerad inom några sekunder.",
     "Redirect" : "Omdirigera",
     "The link leads to %s" : "Länken pekar mot %s",
-    "Continue to %s" : "Fortsätt till %s"
+    "Continue to %s" : "Fortsätt till %s",
+    "Unselect" : "Avmarkera"
 },
 "nplurals=2; plural=(n != 1);");
