@@ -210,8 +210,6 @@ OC.L10N.register(
     "Unimportant" : "Неважливе",
     "Mark not spam" : "Позначити як не спам",
     "Mark as spam" : "Позначити як спам",
-    "Unselect" : "Зняти виділення",
-    "Select" : "Вибрати",
     "Edit tags" : "Редагувати мітки",
     "Snooze" : "Відкласти",
     "Unsnooze" : "Актуальне",
@@ -238,8 +236,19 @@ OC.L10N.register(
     "Could not snooze thread" : "Не вдалося відкласти ланцюг",
     "Thread was unsnoozed" : "Ланцюг знову актуалізовано",
     "Could not unsnooze thread" : "Не вдалося актуалізуати ланцюг",
-    "Forward" : "Переслати",
     "Load more" : "Більше",
+    "_Mark {number} read_::_Mark {number} read_" : ["Позначити {number} прочитаним","Позначити {number} прочитаними","Позначити {number} прочитаними","Позначити {number} прочитаними"],
+    "_Mark {number} unread_::_Mark {number} unread_" : ["Позначити {number} непрочитаним","Позначити {number} непрочитаними","Позначити {number} непрочитаними","Позначити {number} непрочитаними"],
+    "_Mark {number} as important_::_Mark {number} as important_" : ["Позначити {number} важливим","Позначити {number} важливими","Позначити {number} важливими","Позначити {number} важливими"],
+    "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["Позначити {number} неважливим","Позначити {number} неважливими","Позначити {number} неважливими","Позначити {number} неважливими"],
+    "_Unfavorite {number}_::_Unfavorite {number}_" : ["Без зірки {number}","Без зірки {number}","Без зірки {number}","Без зірочки {number}"],
+    "_Favorite {number}_::_Favorite {number}_" : ["Із зіркою {number}","Із зіркою {number}","Із зіркою {number}","Із зірочкою {number}"],
+    "_Unselect {number}_::_Unselect {number}_" : ["Не вибрано {number}","Не вибрано {number}","Не вибрано {number}","Не вибрано {number}"],
+    "_Mark {number} as spam_::_Mark {number} as spam_" : ["Позначити {number} спамом","Позначити {number} спамом","Позначити {number} спамом","Позначити {number} спамом"],
+    "_Mark {number} as not spam_::_Mark {number} as not spam_" : ["Позначити {number} не спамом","Позначити {number} не спамом","Позначити {number} не спамом","Позначити {number} не спамом"],
+    "_Edit tags for {number}_::_Edit tags for {number}_" : ["Редагувати мітки для {number}","Редагувати мітки для {number}","Редагувати мітки для {number}","Редагувати мітки для {number}"],
+    "_Move {number} thread_::_Move {number} threads_" : ["Перемістити {number} ланцюжок","Перемістити {number} ланцюжки","Перемістити {number} ланцюжків","Перемістити {number} ланцюжків"],
+    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Переслати {number} як вкладення","Переслати {number} як вкладення","Переслати {number} як вкладення","Переслати {number} як вкладення"],
     "Report this bug" : "Повідомити про помилку",
     "All day" : "Весь день",
     "Select calendar" : "Виберіть календар",
@@ -254,6 +263,7 @@ OC.L10N.register(
     "You have been invited to an event" : "Вас запросили на подію",
     "This event was cancelled" : "Цей захід було скасовано",
     "Save to" : "Зберегти в",
+    "Select" : "Вибрати",
     "Comment" : "Коментар",
     "Accept" : "Прийняти",
     "Decline" : "Відхилити",
@@ -283,7 +293,9 @@ OC.L10N.register(
     "The sender of this message has asked to be notified when you read this message." : "Відправник цього повідомлення попросив його/її повідомити, коли ви прочитаєте це повідомлення.",
     "Notify the sender" : "Повідомити відправника",
     "You sent a read confirmation to the sender of this message." : "Ви надіслали підтвердження про прочитання відправнику цього повідомлення.",
+    "Forward" : "Переслати",
     "Move message" : "Перемістити повідомлення",
+    "Translate" : "Перекласти",
     "Forward message as attachment" : "Надіслати повідомлення вкладенням",
     "View source" : "Джерело",
     "Download thread data for debugging" : "Звантажити дані ланцюжка для зневадження",
@@ -399,6 +411,8 @@ OC.L10N.register(
     "Add" : "Додати",
     "Copied email address to clipboard" : "Адресу електронної пошти скопійовано до буферу обміну",
     "Could not copy email address to clipboard" : "Не вдалося скопіювати адресу електронної пошти до буфера обміну",
+    "Show less" : "Показувати менше",
+    "Show more" : "Показати більше",
     "Search in mailbox" : "Шукати в поштовій скринці",
     "Close" : "Закрити",
     "Search parameters" : "Параметри пошуку",
@@ -476,6 +490,8 @@ OC.L10N.register(
     "Go to latest message" : "Перейти до останнього повідомлення",
     "Go to newest message" : "Перейти до найновішого повідомлення",
     "{name} Assistant" : "Асистент {name}",
+    "Translate from" : "Перекласти з",
+    "Translate to" : "Перекласти",
     "Disable trash retention by leaving the field empty or setting it to 0. Only mails deleted after enabling trash retention will be processed." : "Вимкніть зберігання кошика, для цього залиште поле порожнім або встановіть його значення у 0. Це буде застосовано лише до листів, які було вилучено після увімкнення зберігання кошика.",
     "No senders are trusted at the moment." : "Наразі відсутні довірені відправники.",
     "Could not remove trusted sender {sender}" : "Не вдалося вилучити довіреного відправника {sender}",
@@ -556,8 +572,6 @@ OC.L10N.register(
     "Redirect" : "Перенаправлення",
     "The link leads to %s" : "Посилання веде до %s",
     "Continue to %s" : "Перейти до %s",
-    "Sieve filter rules" : "Правила фільтру Sieve",
-    "Sieve filter server" : "Сервер Sieve для фільтрування",
-    "Account creation" : "Створення облікового запису"
+    "Unselect" : "Зняти виділення"
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
