@@ -97,8 +97,6 @@ OC.L10N.register(
     "Read" : "Đọc",
     "Mark not spam" : "Đánh dấu không phải là thư rác",
     "Mark as spam" : "đánh dấu spam",
-    "Unselect" : "Bỏ chọn",
-    "Select" : "Select",
     "Edit tags" : "Sửa thẻ",
     "More actions" : "Nhiều hành động hơn",
     "Back" : "Quay lại",
@@ -107,13 +105,19 @@ OC.L10N.register(
     "Blind copy recipients only" : "Chỉ người nhận bản sao ẩn",
     "No trash mailbox configured" : "Không có hộp thư thùng rác nào được định cấu hình",
     "Could not delete message" : "Không thể xóa tin nhắn",
-    "Forward" : "Chuyển tiếp",
     "Load more" : "Tải thêm",
+    "_Mark {number} read_::_Mark {number} read_" : ["Đánh dấu {number} đã đọc"],
+    "_Mark {number} unread_::_Mark {number} unread_" : ["Đánh dấu {number} là chưa đọc"],
+    "_Unfavorite {number}_::_Unfavorite {number}_" : ["Bỏ yêu thích {number}"],
+    "_Favorite {number}_::_Favorite {number}_" : ["Yêu thích {number}"],
+    "_Unselect {number}_::_Unselect {number}_" : ["Bỏ chọn {number}"],
+    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Chuyển tiếp {number} dưới dạng tệp đính kèm"],
     "Report this bug" : "Báo cáo lỗi này",
     "All day" : "Cả ngày",
     "Description" : "Mô tả",
     "Create" : "‎Tạo‎",
     "Could not create event" : "Không thể tạo sự kiện",
+    "Select" : "Select",
     "Comment" : "Bình luận",
     "Accept" : "Đồng ý",
     "Decline" : "Từ chối",
@@ -133,6 +137,8 @@ OC.L10N.register(
     "Notify the sender" : "Thông báo cho người gửi",
     "You sent a read confirmation to the sender of this message." : "Bạn đã gửi xác nhận đã đọc cho người gửi tin nhắn này.",
     "Could not send mdn" : "Không thể gửi mdn",
+    "Forward" : "Chuyển tiếp",
+    "Translate" : "Dịch",
     "View source" : "Xem nguồn",
     "Download thread data for debugging" : "Tải xuống dữ liệu chuỗi để gỡ lỗi",
     "Message body" : "Nội dung thư",
@@ -281,7 +287,6 @@ OC.L10N.register(
     "Redirect" : "Chuyển hướng",
     "The link leads to %s" : "Liên kết dẫn đến %s",
     "Continue to %s" : "Tiếp tục %s",
-    "Sieve filter rules" : "Quy tắc lọc Sieve",
-    "Sieve filter server" : "Máy chủ lọc Sieve"
+    "Unselect" : "Bỏ chọn"
 },
 "nplurals=1; plural=0;");
