@@ -53,6 +53,7 @@ use OCA\Mail\Listener\OutOfOfficeListener;
 use OCA\Mail\Listener\SpamReportListener;
 use OCA\Mail\Listener\UserDeletedListener;
 use OCA\Mail\Notification\Notifier;
+use OCA\Mail\Provider\MailProvider;
 use OCA\Mail\Search\FilteringProvider;
 use OCA\Mail\Search\Provider;
 use OCA\Mail\Service\Attachment\AttachmentService;
@@ -65,6 +66,7 @@ use OCA\Mail\Service\MailTransmission;
 use OCA\Mail\Service\Search\MailSearch;
 use OCA\Mail\Service\TrustedSenderService;
 use OCA\Mail\Service\UserPreferenceService;
+use OCA\Mail\SetupChecks\MailTransport;
 use OCA\Mail\Vendor\Favicon\Favicon;
 use OCP\AppFramework\App;
 use OCP\AppFramework\Bootstrap\IBootContext;
@@ -165,8 +167,14 @@ class Application extends App implements IBootstrap {
 			$context->registerSearchProvider(Provider::class);
 		}
 
+		// Added in version 4.0.0
+		// Disabled in v4.1.0 due to stability concerns
+		//$context->registerMailProvider(MailProvider::class);
+
 		$context->registerNotifierService(Notifier::class);
 
+		$context->registerSetupCheck(MailTransport::class);
+
 		// bypass Horde Translation system
 		Horde_Translation::setHandler('Horde_Imap_Client', new HordeTranslationHandler());
 		Horde_Translation::setHandler('Horde_Mime', new HordeTranslationHandler());
