@@ -3,24 +3,8 @@
 declare(strict_types=1);
 
 /**
- * @copyright 2019 Christoph Wurst <christoph@winzerhof-wurst.at>
- *
- * @author 2019 Christoph Wurst <christoph@winzerhof-wurst.at>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-FileCopyrightText: 2019 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Mail\Db;
@@ -95,7 +79,7 @@ class Mailbox extends Entity implements JsonSerializable {
 
 	/**
 	 * @var int
-	 * Lock timeout for sync (5 minutes)
+	 *          Lock timeout for sync (5 minutes)
 	 */
 	public const LOCK_TIMEOUT = 300;
 
@@ -126,7 +110,7 @@ class Mailbox extends Entity implements JsonSerializable {
 				strtolower($specialUse),
 				'\\'
 			),
-			array_map("strtolower", $this->getSpecialUseParsed()),
+			array_map('strtolower', $this->getSpecialUseParsed()),
 			true
 		);
 	}
