@@ -3,25 +3,8 @@
 declare(strict_types=1);
 
 /**
- * @copyright 2020 Christoph Wurst <christoph@winzerhof-wurst.at>
- *
- * @author 2020 Christoph Wurst <christoph@winzerhof-wurst.at>
- * @author 2023 Richard Steinmetz <richard@steinmetz.cloud>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-FileCopyrightText: 2020 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Mail\Service\Classification;
@@ -215,10 +198,10 @@ class ImportanceClassifier {
 			$perf->end();
 			return;
 		}
-		$perf->step("train and validate classifier with training and validation sets");
+		$perf->step('train and validate classifier with training and validation sets');
 
 		$estimator = $this->trainClassifier($dataSet);
-		$perf->step("train classifier with full data set");
+		$perf->step('train classifier with full data set');
 
 		$classifier->setAccountId($account->getId());
 		$classifier->setDuration($perf->end());
@@ -282,7 +265,7 @@ class ImportanceClassifier {
 		return array_map(function (Message $message) {
 			$sender = $message->getFrom()->first();
 			if ($sender === null) {
-				throw new RuntimeException("This should not happen");
+				throw new RuntimeException('This should not happen');
 			}
 
 			return [
@@ -392,7 +375,7 @@ class ImportanceClassifier {
 		 * Ref https://en.wikipedia.org/wiki/Precision_and_recall
 		 * Ref https://en.wikipedia.org/wiki/F1_score
 		 */
-		$logger->debug("classification report: " . json_encode([
+		$logger->debug('classification report: ' . json_encode([
 			'recall' => $recallImportant,
 			'precision' => $precisionImportant,
 			'f1Score' => $f1ScoreImportant,
